@@ -189,8 +189,18 @@ sub box_val {
         if (not($type)) {
             /^\-?\d+$/ ? NUMBER->new($o) : STRING->new($o);
         }
-        elsif ($type =~ /^(?:ARRAY|HASH|SCALAR|REF|Regexp)$/) {
-            XXX $o, "Lingy can't box this object yet";
+        elsif ($type eq 'HASH') {
+            HASHMAP->new([
+                map box_val($_), %$o
+            ]);
+        }
+        elsif ($type eq 'ARRAY') {
+            VECTOR->new([
+                map box_val($_), %$o
+            ]);
+        }
+        elsif ($type =~ /^(?:SCALAR|REF|Regexp)$/) {
+            XXX($o, "Lingy can't box this object yet");
         } else {
             $o;
         }
@@ -199,7 +209,11 @@ sub box_val {
 
 sub unbox_val {
     my ($obj) = @_;
-    ref($obj) =~ /^Lingy::(String|Number|Boolean|Fn)$/ ? $obj->unbox : $obj;
+    ref($obj) =~ /^
+        Lingy::(
+            String|Number|Boolean|Nil|HashMap|Vector|Fn
+        )
+    $/x ? $obj->unbox : $obj;
 }
 
 sub assert_args {
